Function console_utils::control::flush
source · pub fn flush()Expand description
Flushes the output buffer, ensuring that all content is written to the console.
pub fn flush()Flushes the output buffer, ensuring that all content is written to the console.