Function console_utils::control::move_cursor_down
source · pub fn move_cursor_down(n: usize)Expand description
Moves the cursor down by the specified number of lines.
Arguments
n- The number of lines to move the cursor down.