Function console_utils::control::move_cursor_left
source · pub fn move_cursor_left(n: usize)Expand description
Moves the cursor to the left by the specified number of characters.
Arguments
n- The number of characters to move the cursor to the left.