Function console_utils::control::move_cursor_right
source · pub fn move_cursor_right(n: usize)Expand description
Moves the cursor to the right by the specified number of characters.
Arguments
n- The number of characters to move the cursor to the right.