Function console_utils::control::move_cursor_up
source · pub fn move_cursor_up(n: usize)Expand description
Moves the cursor up by the specified number of lines.
Arguments
n- The number of lines to move the cursor up.
pub fn move_cursor_up(n: usize)Moves the cursor up by the specified number of lines.
n - The number of lines to move the cursor up.