pub fn move_cursor_left(n: usize)
Moves the cursor to the left by the specified number of characters.

Arguments

  • n - The number of characters to move the cursor to the left.

Example

use console_utils::move_cursor_left;

// Move the cursor left by 4 characters
move_cursor_left(4);