Function console_utils::read::read_key
source · pub fn read_key() -> Option<Key>Expand description
Read Key Function
The read_key function reads a single key event from the console input
and returns a Key enum.
pub fn read_key() -> Option<Key>The read_key function reads a single key event from the console input
and returns a Key enum.