pub fn clear_line()
Clears the current line in the console.

This function uses ANSI escape codes to clear the entire line and move the cursor to the beginning of the line.

Example

use console_utils::control::clear_line;

// Clear the current line
clear_line();