pub fn move_cursor_down(n: usize)
Moves the cursor down by the specified number of lines.

Arguments

  • n - The number of lines to move the cursor down.

Example

use console_utils::control::move_cursor_down;

// Move the cursor down by 2 lines
move_cursor_down(2);