pub fn move_cursor_right(n: usize)
Moves the cursor to the right by the specified number of characters.

Arguments

  • n - The number of characters to move the cursor to the right.

Example

use console_utils::control::move_cursor_right;

// Move the cursor right by 5 characters
move_cursor_right(5);