pub fn move_cursor_up(n: usize)
Moves the cursor up by the specified number of lines.

Arguments

  • n - The number of lines to move the cursor up.

Example

use console_utils::control::move_cursor_up;

// Move the cursor up by 3 lines
move_cursor_up(3);